@@ -1,4 +1,5 @@
 import enum
+import json
 import logging
 import re
 from functools import wraps
@@ -339,9 +340,11 @@ class WhileProcedure(LoopProcedure):
                 if isinstance(v, str):
                     # noinspection PyBroadException
                     try:
-                        context[k] = eval('"{}"'.format(re.sub(r'(^|[^\\\])"', '\1\\"', v)))
-                    except:
-                        pass
+                        context[k] = eval('"{}"'.format(re.sub(r'(^|[^\\])"', '\1\\"', v)))
+                    except Exception as e:
+                        logger.warning('Could not parse value for context variable {}={}'.format(k, v))
+                        logger.warning('Context: {}'.format(json.dumps(context)))
+                        logger.exception(e)
 
         return context
 
@@ -452,9 +455,11 @@ class IfProcedure(Procedure):
             except:
                 if isinstance(v, str):
                     try:
-                        exec('{}="{}"'.format(k, re.sub(r'(^|[^\\\])"', '\1\\"', v)))
-                    except:
-                        pass
+                        exec('{}="{}"'.format(k, re.sub(r'(^|[^\\])"', '\1\\"', v)))
+                    except Exception as e:
+                        logger.warning('Could not set context variable {}={}'.format(k, v))
+                        logger.warning('Context: {}'.format(json.dumps(context)))
+                        logger.exception(e)
 
         condition_true = eval(self.condition)
         response = Response()
