@@ -1,12 +1,12 @@
-import logging
 import unittest
 
-from .context import config_file
 from platypush.event.hook import EventCondition
 from platypush.message.event.ping import PingEvent
 
+from . import BaseTest
 
-class TestEventParse(unittest.TestCase):
+
+class TestEventParse(BaseTest):
     def setUp(self):
         self.condition = EventCondition.build({
             'type': 'platypush.message.event.ping.PingEvent',
@@ -14,7 +14,6 @@ class TestEventParse(unittest.TestCase):
         })
 
     def test_event_parse(self):
-        logging.info('Starting test on configuration file: {}'.format(config_file))
         message = "GARBAGE GARBAGE this is the answer: 42"
         event = PingEvent(message=message)
         result = event.matches_condition(self.condition)
